@@ -71,14 +71,11 @@ class BaseDataManager(object):
                 exist, data = has_items(result)
                 if not exist:
                     break
-                if self.with_last_id:
-                    last_id = (
-                        getattr(data[-1], self.last_id_field)
-                        if isinstance(data, list)
-                        else getattr(list(data)[-1], self.last_id_field)
-                    )
-                data = self.serialize_data(data, fields)
+                data = self.serialize_data(
+                    data, fields + [self.last_id_field] if self.with_last_id else fields
+                )
                 for row in data:
+                    last_id = row.pop(self.last_id_field, None)
                     writer.writerow(row)
                 skip += self.query_limit
                 if skip > limit:
